'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

exports['default'] = connectContext;

var _react = require('react');

var _reactRedux = require('react-redux');

function noop() {}

// Calling `mapDispatchToProps` with a dummy disptach function in order to get the keys out.
// Hopefully your implementation doesn't have side effects.
function getChildContextTypes(mapDispatchToProps) {
  var childContextTypes = {};

  Object.keys(mapDispatchToProps(noop)).forEach(function (key) {
    // TODO: allow objectOf(func)
    childContextTypes[key] = _react.PropTypes.func;
  });

  return childContextTypes;
}

// Put the all action creators in props (like a the `connect` function does),
// but also "save" them in an `actionCreators` object.
function wrapDispatchToProps(mapDispatchToProps) {
  return function (dispatch) {
    var actionCreators = mapDispatchToProps(dispatch);
    return _extends({
      actionCreators: actionCreators
    }, actionCreators);
  };
}

function overwriteChildContextTypes(component, childContextTypes) {
  Object.assign(component.childContextTypes, childContextTypes);
}

// Get the original child context and assign all the `actionCreators` we "saved" in `props` on to it.
function overwriteGetChildContext(component) {
  var originalGetChildContext = component.prototype.getChildContext;

  // using `function` so that `this` points to the actual instance of the component.
  component.prototype.getChildContext = function getChildContext() {
    return Object.assign(originalGetChildContext.call(this), this.props.actionCreators);
  };
}

/**
 * Enhanced version of redux' connect, that puts all action creators
 * into the child context of the component.
 *
 * @param mapStateToProps {Function}
 * @param mapDispatchToProps {Function} Must be free of side effects!
 * @returns {Function}
 */

function connectContext(mapStateToProps, mapDispatchToProps) {
  var childContextTypes = getChildContextTypes(mapDispatchToProps);
  var wrappedMapDispatchToProps = wrapDispatchToProps(mapDispatchToProps);

  return function (component) {
    overwriteChildContextTypes(component, childContextTypes);
    overwriteGetChildContext(component);
    return _reactRedux.connect(mapStateToProps, wrappedMapDispatchToProps)(component);
  };
}

module.exports = exports['default'];